# Generated file
# - do not overwrite
# - do not include in git
from collections import namedtuple

BuildInfo = namedtuple(
    'BuildInfo',
    ['version', 'built_at', 'sha', 'branch', 'tag'],
)

BUILD_INFO = BuildInfo(
    version='v4.18.3~312000e',
    built_at='2025-05-24 06:12:17Z',
    sha='312000e4bc3deae312e1af2f76e5406fc1eb36fd',
    branch='HEAD',
    tag='v4.18.3',
)
